@@ -1,4 +1,8 @@
+#![allow(clippy::new_without_default)]
+#![allow(clippy::or_fun_call)]
+
 mod cf;
+mod context;
 mod date;
 pub mod durable;
 mod env;
@@ -11,12 +15,14 @@ mod request;
 mod request_init;
 mod response;
 mod router;
+mod schedule;
 
 #[doc(hidden)]
 use std::result::Result as StdResult;
 
 pub type Result<T> = StdResult<T, error::Error>;
 
+pub use crate::context::Context;
 pub use crate::date::{Date, DateInit};
 pub use crate::env::Env;
 pub use crate::error::Error;
@@ -28,10 +34,11 @@ pub use crate::request::Request;
 pub use crate::request_init::*;
 pub use crate::response::{Response, ResponseBody};
 pub use crate::router::{RouteContext, RouteParams, Router};
+pub use crate::schedule::*;
 pub use cf::Cf;
 pub use url::Url;
 
-pub use worker_sys::console_log;
+pub use worker_sys::{console_debug, console_error, console_log, console_warn};
 
 pub use crate::durable::*;
 pub use worker_macros::{durable_object, event};
