@@ -52,19 +52,21 @@ pub struct Router<'a, D> {
 /// Container for a route's parsed parameters, data, and environment bindings from the Runtime (such
 /// as KV Stores, Durable Objects, Variables, and Secrets).
 pub struct RouteContext<D> {
-    data: D,
-    env: Env,
+    pub data: D,
+    pub env: Env,
     params: RouteParams,
 }
 
 impl<D> RouteContext<D> {
     /// Get a reference to the generic associated data provided to the `Router`.
+    #[deprecated(since = "0.0.8", note = "please use the `data` field directly")]
     pub fn data(&self) -> &D {
         &self.data
     }
 
     /// Get the `Env` for this Worker. Typically users should opt for the `secret`, `var`, `kv` and
     /// `durable_object` methods on the `RouteContext` instead.
+    #[deprecated(since = "0.0.8", note = "please use the `env` field directly")]
     pub fn get_env(self) -> Env {
         self.env
     }
